==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/ConnectToMongoDbTaskPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.ConnectToMongoDbTaskPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Properties for the task that validates the connection to and provides information about a MongoDB server
 * @property clientData Key value pairs of client data to attach meta data information to task
 * @property input Describes a connection to a MongoDB data source
 * @property taskType Task type.
 * Expected value is 'Connect.MongoDb'.
 */
public data class ConnectToMongoDbTaskPropertiesArgs(
    public val clientData: Output<Map<String, String>>? = null,
    public val input: Output<MongoDbConnectionInfoArgs>? = null,
    public val taskType: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.ConnectToMongoDbTaskPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.ConnectToMongoDbTaskPropertiesArgs =
        com.pulumi.azurenative.datamigration.inputs.ConnectToMongoDbTaskPropertiesArgs.builder()
            .clientData(
                clientData?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .input(input?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .taskType(taskType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectToMongoDbTaskPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectToMongoDbTaskPropertiesArgsBuilder internal constructor() {
    private var clientData: Output<Map<String, String>>? = null

    private var input: Output<MongoDbConnectionInfoArgs>? = null

    private var taskType: Output<String>? = null

    /**
     * @param value Key value pairs of client data to attach meta data information to task
     */
    @JvmName("orqxtmwxtxhkumna")
    public suspend fun clientData(`value`: Output<Map<String, String>>) {
        this.clientData = value
    }

    /**
     * @param value Describes a connection to a MongoDB data source
     */
    @JvmName("ovqkakeegdpmagvb")
    public suspend fun input(`value`: Output<MongoDbConnectionInfoArgs>) {
        this.input = value
    }

    /**
     * @param value Task type.
     * Expected value is 'Connect.MongoDb'.
     */
    @JvmName("iitbaglyjkiccmdp")
    public suspend fun taskType(`value`: Output<String>) {
        this.taskType = value
    }

    /**
     * @param value Key value pairs of client data to attach meta data information to task
     */
    @JvmName("fkepgwrelhgjqvgv")
    public suspend fun clientData(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientData = mapped
    }

    /**
     * @param values Key value pairs of client data to attach meta data information to task
     */
    @JvmName("bapcbgktyyqryeiw")
    public fun clientData(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clientData = mapped
    }

    /**
     * @param value Describes a connection to a MongoDB data source
     */
    @JvmName("evsreylvxcbepxxg")
    public suspend fun input(`value`: MongoDbConnectionInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.input = mapped
    }

    /**
     * @param argument Describes a connection to a MongoDB data source
     */
    @JvmName("dckbritkrckplknv")
    public suspend fun input(argument: suspend MongoDbConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MongoDbConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.input = mapped
    }

    /**
     * @param value Task type.
     * Expected value is 'Connect.MongoDb'.
     */
    @JvmName("fjyxynsmntxxmhvg")
    public suspend fun taskType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.taskType = mapped
    }

    internal fun build(): ConnectToMongoDbTaskPropertiesArgs = ConnectToMongoDbTaskPropertiesArgs(
        clientData = clientData,
        input = input,
        taskType = taskType ?: throw PulumiNullFieldException("taskType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/ConnectToMongoDbTaskPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.ConnectToMongoDbTaskPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Properties for the task that validates the connection to and provides information about a MongoDB server
 * @property clientData Key value pairs of client data to attach meta data information to task
 * @property input Describes a connection to a MongoDB data source
 * @property taskType Task type.
 * Expected value is 'Connect.MongoDb'.
 */
public data class ConnectToMongoDbTaskPropertiesArgs(
    public val clientData: Output<Map<String, String>>? = null,
    public val input: Output<MongoDbConnectionInfoArgs>? = null,
    public val taskType: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.ConnectToMongoDbTaskPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.ConnectToMongoDbTaskPropertiesArgs =
        com.pulumi.azurenative.datamigration.inputs.ConnectToMongoDbTaskPropertiesArgs.builder()
            .clientData(
                clientData?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .input(input?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .taskType(taskType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectToMongoDbTaskPropertiesArgs].
 */
@PulumiTagMarker
public class ConnectToMongoDbTaskPropertiesArgsBuilder internal constructor() {
    private var clientData: Output<Map<String, String>>? = null

    private var input: Output<MongoDbConnectionInfoArgs>? = null

    private var taskType: Output<String>? = null

    /**
     * @param value Key value pairs of client data to attach meta data information to task
     */
    @JvmName("jhvjgisjffptxxyk")
    public suspend fun clientData(`value`: Output<Map<String, String>>) {
        this.clientData = value
    }

    /**
     * @param value Describes a connection to a MongoDB data source
     */
    @JvmName("nhllahqxrjivuctl")
    public suspend fun input(`value`: Output<MongoDbConnectionInfoArgs>) {
        this.input = value
    }

    /**
     * @param value Task type.
     * Expected value is 'Connect.MongoDb'.
     */
    @JvmName("wwuwvyakskwykkpo")
    public suspend fun taskType(`value`: Output<String>) {
        this.taskType = value
    }

    /**
     * @param value Key value pairs of client data to attach meta data information to task
     */
    @JvmName("gpxgucyfldnaopkn")
    public suspend fun clientData(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientData = mapped
    }

    /**
     * @param values Key value pairs of client data to attach meta data information to task
     */
    @JvmName("rjheqdsjqfwhokwq")
    public fun clientData(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clientData = mapped
    }

    /**
     * @param value Describes a connection to a MongoDB data source
     */
    @JvmName("vvscvuxikkpmmvjx")
    public suspend fun input(`value`: MongoDbConnectionInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.input = mapped
    }

    /**
     * @param argument Describes a connection to a MongoDB data source
     */
    @JvmName("cdbhopxxnhitlyfa")
    public suspend fun input(argument: suspend MongoDbConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MongoDbConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.input = mapped
    }

    /**
     * @param value Task type.
     * Expected value is 'Connect.MongoDb'.
     */
    @JvmName("yobvlvdirwbkxcre")
    public suspend fun taskType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.taskType = mapped
    }

    internal fun build(): ConnectToMongoDbTaskPropertiesArgs = ConnectToMongoDbTaskPropertiesArgs(
        clientData = clientData,
        input = input,
        taskType = taskType ?: throw PulumiNullFieldException("taskType"),
    )
}
